@@ -9,7 +9,6 @@ import time
 import traceback
 import sys
 from importlib import import_module
-
 import requests
 from qg_eureka import EurekaClient
 from qg_tool.tool import get_host_ip
@@ -33,7 +32,7 @@ for member in inspect.getmembers(bootstrap, is_config):
 
 
 def init_arg(name, default):
-    if config.get(name, None) is None:
+    if config.get(name, None) is not None:
         pass
     else:
         config[name] = default
@@ -52,38 +51,55 @@ auto_load = init_arg('auto_load', True)
 config_server_name = config['config_server_name']
 app_name = config['app_name']
 eureka_url = config['eureka_url']
-eureka_heart = config['eureka_heart']
-
 eureka = EurekaClient(app_name=app_name, port=port, ip_addr=ip,
                       eureka_url=eureka_url)
 
 
+is_fail = False
+stop = False
+
+
 def register_eureka():
+    eureka_heart = config.get("eureka_heart", 20)
+    eureka_restart_time = config.get("eureka_restart_time", 15)
+
+    def deregister():
+        global stop
+        stop = True
+        eureka.deregister()
+
     def heart():
-        while True:
-            time.sleep(
-                int(eureka_heart) if eureka_heart is not None and eureka_heart != '' else 20)
+        global is_fail
+        global stop
+        while not stop:
             try:
                 eureka.renew()
+                if is_fail:
+                    log.info("eureka连接恢复")
+                    is_fail = False
                 log.debug('eureka renew')
-                continue
-            except:
-                print(f'连不上eureka: {eureka_url}')
-                traceback.print_exc()
-            finally:
+            except Exception as e:
+                is_fail = True
+                log.error(f'连不上eureka: {eureka_url}', exc_info=e)
                 break
-        register_eureka()
+            time.sleep(eureka_heart)
+            continue
+        if not stop:
+            atexit.unregister(deregister)
+            log.info("%s s 后重新注册 eureka" % eureka_restart_time)
+            time.sleep(eureka_restart_time)
+            register_eureka()
 
     try:
         eureka.register()
-        atexit.register(lambda: eureka.deregister())
-
-    except:
-        traceback.print_exc()
-    finally:
-        heart_thread = threading.Thread(target=heart)
-        heart_thread.setDaemon(True)
+        atexit.register(deregister)
+        heart_thread = threading.Thread(target=heart, daemon=True)
         heart_thread.start()
+    except Exception as e:
+        log.error("注册eureka失败", exc_info=e)
+        log.info("%s s 后重新注册 eureka" % eureka_restart_time)
+        time.sleep(eureka_restart_time)
+        register_eureka()
 
 
 def get_app_homepage(name, **kwargs):
